﻿''' <summary>
''' [UC]テキストボックスコントロール
''' </summary>
''' <remarks>
''' 
''' 更新日  ：
''' 更新内容：
''' 
''' </remarks>
Public Class UcTextBox
    Inherits TextBox

#Region "変数"

    'プロパティ用
    Private _allowNewlineCharacter As Boolean = False
    Private _highlightText As Boolean = True
    Private _initialValue As String = ""
    '
    '処理用
    Private mFlag As Boolean = False

#End Region

#Region "プロパティ"

    ''' <summary>
    ''' テキストの取得・設定
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Public Overrides Property Text As String
        Get
            Return MyBase.Text
        End Get
        Set(value As String)
            If Not _allowNewlineCharacter Then '改行コードの置換
                value = value.Replace(vbCr, "")
            End If
            If value.Length < Me.MaxLength Then
                MyBase.Text = value
            Else
                MyBase.Text = value.Substring(1, IIf(IsNothing(Me.MaxLength), 0, Me.MaxLength))
            End If
        End Set
    End Property

#End Region

#Region "プロパティ（新規追加）"

    ''' <summary>
    ''' 改行コード許可の取得・設定
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    <System.ComponentModel.DefaultValue(False)> _
    Public Property AllowNewlineCharacter() As Boolean
        Get
            Return _allowNewlineCharacter
        End Get
        Set(ByVal Value As Boolean)
            _allowNewlineCharacter = Value
        End Set
    End Property

    ''' <summary>
    ''' ハイライトテキストの取得・設定
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    <System.ComponentModel.DefaultValue(True)> _
    Public Property HighlightText() As Boolean
        Get
            Return _highlightText
        End Get
        Set(ByVal Value As Boolean)
            _highlightText = Value
        End Set
    End Property

    ''' <summary>
    ''' 初期値の取得・設定
    ''' </summary>
    ''' <value></value>
    ''' <returns></returns>
    ''' <remarks></remarks>
    <System.ComponentModel.DefaultValue("")> _
    Public Property InitialValue() As String
        Get
            Return _initialValue
        End Get
        Set(ByVal Value As String)
            _initialValue = Value
        End Set
    End Property

#End Region

#Region "イベント"

    ''' <summary>
    ''' フォーカスを移動させる。
    ''' </summary>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Protected Overrides Sub OnKeyDown(e As System.Windows.Forms.KeyEventArgs)
        MyBase.OnKeyDown(e)
        '
        If e.Handled Then
            Return
        End If
        '
        Select Case e.KeyCode
            Case Keys.Enter
                If Control.ModifierKeys = Keys.Shift Then '前のコントロールへ移動
                    Me.TopLevelControl.SelectNextControl(Me, False, True, True, True) : e.Handled = True
                Else '次のコントロールへ移動
                    Me.TopLevelControl.SelectNextControl(Me, True, True, True, True) : e.Handled = True
                End If
            Case Keys.Up '前のコントロールへ移動
                Me.TopLevelControl.SelectNextControl(Me, False, True, True, True) : e.Handled = True
                '
                e.Handled = True
            Case Keys.Down '次のコントロールへ移動
                Me.TopLevelControl.SelectNextControl(Me, True, True, True, True) : e.Handled = True
            Case Else
                ''
        End Select
    End Sub

    ''' <summary>
    ''' フォーカス取得時にハイライトにする。（キー移動）
    ''' </summary>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Protected Overrides Sub OnEnter(e As System.EventArgs)
        MyBase.OnEnter(e)
        '
        If _highlightText Then
            Me.SelectAll()
            If Control.MouseButtons <> Windows.Forms.MouseButtons.None Then
                mFlag = True
            End If
        End If
    End Sub

    ''' <summary>
    ''' フォーカス取得時にハイライトにする。（マウス移動）
    ''' </summary>
    ''' <param name="e"></param>
    ''' <remarks></remarks>
    Protected Overrides Sub OnMouseDown(e As System.Windows.Forms.MouseEventArgs)
        MyBase.OnMouseDown(e)
        '
        If _highlightText Then
            If mFlag Then
                Me.SelectAll()
                mFlag = False
            End If
        End If
    End Sub

#End Region

End Class
